From 1e357dd7acd8eaabef6e52153f6d23ad7cde667f Mon Sep 17 00:00:00 2001
From: Sebastien Zwickert <dilaroga@free.fr>
Date: Thu, 29 Jul 2010 22:36:14 +0200
Subject: [PATCH 1/2] MacOS: manage the mouse events to allow DVD navigation.

---
 modules/video_output/macosx.m |   96 +++++++++++++++++++++++++++++++++++++++++
 1 files changed, 96 insertions(+), 0 deletions(-)

diff --git a/modules/video_output/macosx.m b/modules/video_output/macosx.m
index 5bacb08..61a5ab4 100644
--- a/modules/video_output/macosx.m
+++ b/modules/video_output/macosx.m
@@ -599,4 +599,100 @@ static void OpenglSwap(vout_opengl_t *gl)
 {
     return YES;
 }
+
+- (BOOL)acceptsFirstResponder
+{
+    return YES;
+}
+
+- (BOOL)isFlipped
+{
+    return YES;
+}
+
+- (void)mouseMoved:(NSEvent *)theEvent
+{
+    if (var_InheritBool(vd, "mouse-events"))
+    {
+        NSPoint curPoint = [self convertPoint:[theEvent locationInWindow] fromView:nil];
+
+        if (![self mouse:curPoint inRect:[self bounds]])
+            return;
+
+        int viewWidth = (int)[self bounds].size.width;
+        int viewHeight = (int)[self bounds].size.height;
+
+        if (viewWidth > 0 && viewHeight > 0)
+        {
+            vout_display_place_t place;
+
+            vout_display_cfg_t cfg = *vd->cfg;
+            cfg.display.width  = viewWidth;
+            cfg.display.height = viewHeight;
+
+            vout_display_PlacePicture(&place, &vd->source, &cfg, false);
+
+            const unsigned x = (((int)curPoint.x) - place.x) *
+                                    vd->source.i_visible_width / place.width;
+            const unsigned y = (((int)curPoint.y) - place.y) *
+                                    vd->source.i_visible_height / place.height;
+
+            vout_display_SendEventMouseMoved(vd, x, y);
+        }
+    }
+    else
+    {
+        vout_display_sys_t *sys = vd->sys;
+        if (sys->container && [sys->container respondsToSelector:@selector(mouseMoved:)])
+            [sys->container mouseMoved:theEvent];
+    }
+
+}
+
+- (void)mouseDown:(NSEvent *)theEvent
+{
+    if (var_InheritBool(vd, "mouse-events"))
+    {
+        switch ([theEvent type])
+        {
+            case NSLeftMouseDown:
+            {
+                vout_display_SendEventMousePressed(vd, MOUSE_BUTTON_LEFT);
+                break;
+            }
+            default:
+                break;
+        }
+    }
+    else
+    {
+        vout_display_sys_t *sys = vd->sys;
+        if (sys->container && [sys->container respondsToSelector:@selector(mouseDown:)])
+            [sys->container mouseDown:theEvent];
+    }
+}
+
+- (void)mouseUp:(NSEvent *)theEvent
+{
+    if (var_InheritBool(vd, "mouse-events"))
+    {
+        switch ([theEvent type])
+        {
+            case NSLeftMouseUp:
+            {
+                vout_display_SendEventMouseReleased(vd, MOUSE_BUTTON_LEFT);
+                break;
+            }
+            default:
+                break;
+        }
+    }
+    else
+    {
+        vout_display_sys_t *sys = vd->sys;
+        if (sys->container && [sys->container respondsToSelector:@selector(mouseUp:)])
+            [sys->container mouseUp:theEvent];
+    }
+}
+
 @end
-- 
1.6.1.3

